CarbTestAddon = CreateFrame("Frame", "CarbTestAddon", UIParent); --Creates a new UI frame called "CarbTestAddon"
CarbTestAddon.Name = "CarbTestAddon";

function CarbTestAddon:OnEvent(event,arg1)
	if (event == "ADDON_LOADED" and arg1 == "CarbTestAddon") then
		self:Initialize();
	elseif(event == "WORLD_MAP_UPDATE") then
		self:AddPoints();
		self:AddShapes();
	end
end;

function CarbTestAddon:Initialize() -- Initialize the addon
	self:UnregisterEvent("ADDON_LOADED");
	self:RegisterEvent("WORLD_MAP_UPDATE"); -- Catches when the WorldMap is updated
	
	--------------------------------------------
	-- Store all names for all Zones & Continent
	--------------------------------------------
		self.ContNZoneNames = {GetMapContinents()}; -- Array that stores the Continent & Zone Names Use CarbTestAddon.ContNZoneNames[##Continent Number##][##Zone Number##]
		for Key,Value in pairs(self.ContNZoneNames) do
			self.ContNZoneNames[Key] = {GetMapZones(Key)};
			self.ContNZoneNames[Key]["Name"] = Value; -- Moves the name up a level
		end;
	--------------------------------------------
	
	self:AddPoints(); -- Adds 4 points to the carbonite map with different colours, locations and shapes
	self:AddShapes(); -- Adds 4 rectangles to the carbonite  map with different colours, locations and sizes
end;

function CarbTestAddon:AddPoints() -- Adds a few basic Points to the current map
	------------------------------------------------------------------------
	-- Setup points/icons and wipe any existing
	------------------------------------------------------------------------
		local icT = "!"..tostring(self.Name); -- Name of the addon e.g. icT = "!CarbTestAddon";
		Nx.MapInitIconType(icT, "WP", "", 10, 10);
		Nx.MapSetIconAlpha(icT, 1); -- Set the Alpha of these points.
		Nx.MapSetIconVisableScale(icT, 0.3); -- Sets the scale these points disapears at.
	------------------------------------------------------------------------
	
	local Cross = {
		["Texture"] = "Interface\\Addons\\CarbTestAddon\\Images\\WE_WhiteCross",
		["Width"] = 5,
		["Height"] = 5,
	};
	
	local Circle = {
		["Texture"] = "Interface\\Addons\\CarbTestAddon\\Images\\WE_WhiteCircle",
		["Width"] = 10,
		["Height"] = 10,
	};
	
	local Square = {
		["Texture"] = "Interface\\Addons\\CarbTestAddon\\Images\\WE_WhiteSquare",
		["Width"] = 10,
		["Height"] = 10,
	};
	
	local Flower = {
		["Texture"] = "Interface\\Addons\\CarbTestAddon\\Images\\WE_WhiteFlower",
		["Width"] = 10,
		["Height"] = 10,
	};
	
	
	local Points = {
		[1] = {
			["X"] = "25",
			["Y"] = "25",
			["Colour"] = "FF0000",
			["Note"] = "Some nice text\nSecond Line... |cffff0000RED|r",
			["Icon"] = Cross;
		},
		[2] = {
			["X"] = "75",
			["Y"] = "25",
			["Colour"] = "0000FF",
			["Note"] = "Some nice text2\nSecond Line... |cffff0000RED|r",
			["Icon"] = Flower;
		},
		[3] = {
			["X"] = "75",
			["Y"] = "75",
			["Colour"] = "007FFF",
			["Note"] = "Some nice text3\nSecond Line... |cffff0000RED|r",
			["Icon"] = Circle;
		},
		[4] = {
			["X"] = "25",
			["Y"] = "75",
			["Colour"] = "007F7F",
			["Note"] = "Some nice text4\nSecond Line... |cffff0000RED|r",
			["Icon"] = Square;
		},
	};
	
	------------------------------------------------------------------------
	-- Add an point/icon
	------------------------------------------------------------------------
		local ZoneName = self.ContNZoneNames[GetCurrentMapContinent()][GetCurrentMapZone()];
		if (ZoneName) then -- Makes sure the ZoneName exists
			for PointNum, PointDetails in pairs(Points) do -- Loop though the points you want to add
				local Icon = Nx.MapAddIconPoint(icT, ZoneName, PointDetails["X"], PointDetails["Y"], PointDetails["Icon"]["Texture"], PointDetails["Colour"]);
				Nx.MapSetIconTip(Icon, PointDetails["Note"]); -- This sets the note(the text that pops up when you mouse over the icon)
			end;
		end;
	------------------------------------------------------------------------
end;

function CarbTestAddon:AddShapes() -- Adds a few basic Shapes to the current map
	------------------------------------------------------------------------
	-- Setup shapes and wipe any existing
	------------------------------------------------------------------------
		local icT_Areas = "!"..tostring(self.Name).."_Areas"; -- Name of the addon e.g. icT_Areas = "!CarbTestAddon_Areas"
		Nx.MapInitIconType(icT_Areas, "ZR");
		Nx.MapSetIconFrameLevel(icT_Areas, -6); -- This is the frame level this icon should have. (Setting it to -6 seems to put it behind icons etc yet in front of the map texture)
		Nx.MapSetIconVisableScale(icT_Areas, 0.3); -- Sets the scale these points disapears at.
	------------------------------------------------------------------------
	
	local Shapes = {
		[1] = {
			["Left"] = "40",
			["Right"] = "50",
			["Top"] = "30",
			["Bottom"] = "40",
			["Colour"] = "FF00004C",
			["Note"] = "Some nice text\nSecond Line... |cffff0000RED|r",
		},
		[2] = {
			["Left"] = "50",
			["Right"] = "70",
			["Top"] = "30",
			["Bottom"] = "40",
			["Colour"] = "8B45134C",
			["Note"] = "Some nice text2\nSecond Line... |cffff0000RED|r",
		},
		[3] = {
			["Left"] = "40",
			["Right"] = "50",
			["Top"] = "50",
			["Bottom"] = "70",
			["Colour"] = "007FFF4C",
			["Note"] = "Some nice text3\nSecond Line... |cffff0000RED|r",
		},
		[4] = {
			["Left"] = "50",
			["Right"] = "70",
			["Top"] = "50",
			["Bottom"] = "70",
			["Colour"] = "007F7F4C",
			["Note"] = "Some nice text4\nSecond Line... |cffff0000RED|r",
		},
	};
	
	------------------------------------------------------------------------
	-- Add an point/icon
	------------------------------------------------------------------------
		local ZoneName = self.ContNZoneNames[GetCurrentMapContinent()][GetCurrentMapZone()];
		if (ZoneName) then
			for ShapeNum, ShapeDetails in pairs(Shapes) do -- Loop though the points you want to add
				local Rectange = Nx.MapAddIconRect(icT_Areas, ZoneName, ShapeDetails["Left"], ShapeDetails["Top"], ShapeDetails["Right"], ShapeDetails["Bottom"], ShapeDetails["Colour"]);
				Nx.MapSetIconTip(Rectange, ShapeDetails["Note"]); -- This sets the note(the text that pops up when you mouse over the Rectange)
			end;
		end;
	------------------------------------------------------------------------
end;

CarbTestAddon:RegisterEvent("ADDON_LOADED"); -- BCatch when this addon has finished loading
CarbTestAddon:SetScript("OnEvent", CarbTestAddon.OnEvent);